@@ -1,4 +1,4 @@
-# $Id: WildCard.pm 207 2009-10-24 20:33:30Z jabra $
+# $Id: WildCard.pm 297 2009-11-16 04:37:07Z jabra $
 package Fierce::Parser::Domain::WildCard;
 {
     our $VERSION = '0.01';
@@ -6,12 +6,12 @@ package Fierce::Parser::Domain::WildCard;
 
     use Object::InsideOut;
 
-    my @bool: Field : Arg(bool) : Get(bool);
+    my @bool : Field : Arg(bool) : Get(bool);
 
     my @starttime : Field : Arg(starttime) : Get(starttime);
     my @endtime : Field : Arg(endtime) : Get(endtime);
     my @starttimestr : Field : Arg(starttimestr) : Get(starttimestr);
     my @endtimestr : Field : Arg(endtimestr) : Get(endtimestr);
-    my @elasptime : Field : Arg(elasptime) : Get(elasptime);
+    my @elapsedtime : Field : Arg(elapsedtime) : Get(elapsedtime);
 }
 1;
